==> nextalarm_0.1.6.tar.gz: nextalarm-0.1.6/src/nalarmsettings.cpp <==
#include "nalarmsettings.h"
#include <QSettings>
#include <QVariant>

/*It's better to use QCoreApplication::setOrganizationName(), QCoreApplication::setOrganizationDomain(),
and QCoreApplication::setApplicationName(). And then only use QSettings() in any place.
But this solution is based on incapsulation strategy, and therefore if this code become a part of lib
and will be used in app without setted appropriate values for application and organization names, then it would probably
 cause some problems */

static const QString organizationName = QString("Avis");
static const QString applicationName = QString("NextAlarm");


//get widget size;
int nalarmsettings::getSize() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("WidgetLines",3).toInt();
}

//set widget size;
void nalarmsettings::setSize(const int &aSize) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("WidgetLines",aSize);
}

//get widget width;
int nalarmsettings::getWidth() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("WidgetWidth",300).toInt();
}

//set widget width;
void nalarmsettings::setWidth(const int &aSize) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("WidgetWidth",aSize);
}

//get color of digits
QColor nalarmsettings::getColor() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    int r = sett.value("DigitsColorR",255).toInt();
    int g = sett.value("DigitsColorG",255).toInt();
    int b = sett.value("DigitsColorB",255).toInt();
    int a = sett.value("DigitsColorA",255).toInt();
    return QColor(r,g,b,a);
}

//set color of digits
void nalarmsettings::setColor(const QColor &aColor) const
{
    QSettings sett(organizationName,applicationName);
    int r = aColor.red();
    int g = aColor.green();
    int b = aColor.blue();
    int a = aColor.alpha();
    sett.setValue("DigitsColorR",r);
    sett.setValue("DigitsColorG",g);
    sett.setValue("DigitsColorB",b);
    sett.setValue("DigitsColorA",a);
}

//get font
QFont nalarmsettings::getFont() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    QFont fnt;
    fnt.setFamily(sett.value("FontFamily",QString("Helvetica")).toString());
    fnt.setBold(sett.value("FontBold",false).toBool());
    fnt.setItalic(sett.value("FontItalic",false).toBool());
    fnt.setPointSize(sett.value("FontSize",16).toInt());
    return fnt;
}

//set font
void nalarmsettings::setFont(const QFont &aFont) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("FontFamily",aFont.family());
    sett.setValue("FontBold",aFont.bold());
    sett.setValue("FontItalic",aFont.italic());
    sett.setValue("FontSize",aFont.pointSize());
}

//get show header
bool nalarmsettings::isShowHeader() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowHeader",true).toBool();
}

//set show header
void nalarmsettings::setShowHeader(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowHeader",aShow);
}

//get show Title
bool nalarmsettings::isShowTitle() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowTitle",true).toBool();
}

//set show Title
void nalarmsettings::setShowTitle(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowTitle",aShow);
}

//get show Remain
bool nalarmsettings::isShowRemain() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowRemain",true).toBool();
}

//set show Remain
void nalarmsettings::setShowRemain(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowRemain",aShow);
}

//get show StdOnly
bool nalarmsettings::isStdOnly() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowStdOnly",true).toBool();
}

//set show StdOnly
void nalarmsettings::setStdOnly(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowStdOnly",aShow);
}

==> nextalarm_0.2.4-1.tar.gz: nextalarm-0.2.4/src/nalarmsettings.cpp <==
#include "nalarmsettings.h"
#include <QSettings>
#include <QVariant>

/*It's better to use QCoreApplication::setOrganizationName(), QCoreApplication::setOrganizationDomain(),
and QCoreApplication::setApplicationName(). And then only use QSettings() in any place.
But this solution is based on incapsulation strategy, and therefore if this code become a part of lib
and will be used in app without setted appropriate values for application and organization names, then it would probably
 cause some problems */

static const QString organizationName = QString("Avis");
static const QString applicationName = QString("NextAlarm");


//get widget size;
int nalarmsettings::getSize() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("WidgetLines",3).toInt();
}

//set widget size;
void nalarmsettings::setSize(const int &aSize) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("WidgetLines",aSize);
}

//get widget width;
int nalarmsettings::getWidth() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("WidgetWidth",300).toInt();
}

//set widget width;
void nalarmsettings::setWidth(const int &aSize) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("WidgetWidth",aSize);
}

//get color of digits
QColor nalarmsettings::getColor() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    int r = sett.value("DigitsColorR",255).toInt();
    int g = sett.value("DigitsColorG",255).toInt();
    int b = sett.value("DigitsColorB",255).toInt();
    int a = sett.value("DigitsColorA",255).toInt();
    return QColor(r,g,b,a);
}

//set color of digits
void nalarmsettings::setColor(const QColor &aColor) const
{
    QSettings sett(organizationName,applicationName);
    int r = aColor.red();
    int g = aColor.green();
    int b = aColor.blue();
    int a = aColor.alpha();
    sett.setValue("DigitsColorR",r);
    sett.setValue("DigitsColorG",g);
    sett.setValue("DigitsColorB",b);
    sett.setValue("DigitsColorA",a);
}

//get font
QFont nalarmsettings::getFont() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    QFont fnt;
    fnt.setFamily(sett.value("FontFamily",QString("Helvetica")).toString());
    fnt.setBold(sett.value("FontBold",false).toBool());
    fnt.setItalic(sett.value("FontItalic",false).toBool());
    fnt.setPointSize(sett.value("FontSize",16).toInt());
    return fnt;
}

//set font
void nalarmsettings::setFont(const QFont &aFont) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("FontFamily",aFont.family());
    sett.setValue("FontBold",aFont.bold());
    sett.setValue("FontItalic",aFont.italic());
    sett.setValue("FontSize",aFont.pointSize());
}

//get show header
bool nalarmsettings::isShowHeader() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowHeader",true).toBool();
}

//set show header
void nalarmsettings::setShowHeader(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowHeader",aShow);
}

//get show Title
bool nalarmsettings::isShowTitle() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowTitle",true).toBool();
}

//set show Title
void nalarmsettings::setShowTitle(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowTitle",aShow);
}

//get show Remain
bool nalarmsettings::isShowRemain() const
{
    QSettings sett(organizationName,applicationName);
    //return widget size
    return sett.value("ShowRemain",true).toBool();
}

//set show Remain
void nalarmsettings::setShowRemain(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowRemain",aShow);
}

//get Alarm Filter
int nalarmsettings::alarmFilter() const
{
    QSettings sett(organizationName,applicationName);
    return sett.value("AlarmFilter",0).toInt();
}

//set Alarm Filter
void nalarmsettings::setAlarmFilter(const int &aFilter) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("AlarmFilter",aFilter);
}

//get show empty
bool nalarmsettings::isShowEmpty() const
{
    QSettings sett(organizationName,applicationName);
    return sett.value("ShowEmpty",true).toBool();
}

//set show empty
void nalarmsettings::setShowEmpty(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowEmpty",aShow);
}

//get show recurrent
bool nalarmsettings::isShowRecurrent() const
{
    QSettings sett(organizationName,applicationName);
    return sett.value("ShowRecurrent",true).toBool();
}

//set show recurrent
void nalarmsettings::setShowRecurrent(const bool &aShow) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("ShowRecurrent",aShow);
}

//get time frame
int nalarmsettings::timeFrame() const
{
    QSettings sett(organizationName,applicationName);
    return sett.value("TimeFrame",24).toInt();
}

//set time frame
void nalarmsettings::setTimeFrame(const int &aFrame) const
{
    QSettings sett(organizationName,applicationName);
    sett.setValue("TimeFrame",aFrame);
}
